@@ -1,18 +1,26 @@
 from __future__ import absolute_import
+
+from . import utils
+from . import activations
+from . import applications
 from . import backend
 from . import datasets
 from . import engine
 from . import layers
 from . import preprocessing
-from . import utils
 from . import wrappers
 from . import callbacks
 from . import constraints
-from . import initializations
+from . import initializers
 from . import metrics
 from . import models
-from . import objectives
+from . import losses
 from . import optimizers
 from . import regularizers
 
-__version__ = '1.1.0'
+# Also importable from root
+from .layers import Input
+from .models import Model
+from .models import Sequential
+
+__version__ = '2.1.0'
